@@ -5,7 +5,8 @@ import (
 	"testing"
 
 	logging "github.com/openshift/cluster-logging-operator/pkg/apis/logging/v1"
-	elasticsearch "github.com/openshift/elasticsearch-operator/pkg/apis/elasticsearch/v1"
+	"github.com/openshift/cluster-logging-operator/pkg/utils"
+	elasticsearch "github.com/openshift/elasticsearch-operator/pkg/apis/logging/v1"
 	esutils "github.com/openshift/elasticsearch-operator/test/utils"
 	v1 "k8s.io/api/core/v1"
 	"k8s.io/apimachinery/pkg/api/resource"
@@ -13,16 +14,16 @@ import (
 
 func TestNewElasticsearchCRWhenResourcesAreUndefined(t *testing.T) {
 
-	cluster := NewClusterLogging(&logging.ClusterLogging{})
-	elasticsearchCR := cluster.newElasticsearchCR("test-app-name")
+	cluster := &logging.ClusterLogging{}
+	elasticsearchCR := newElasticsearchCR(cluster, "test-app-name")
 
 	//check defaults
 	resources := elasticsearchCR.Spec.Spec.Resources
 	if resources.Limits[v1.ResourceMemory] != defaultEsMemory {
 		t.Errorf("Exp. the default memory limit to be %v", defaultEsMemory)
 	}
-	if resources.Limits[v1.ResourceCPU] != defaultEsCpuRequest {
-		t.Errorf("Exp. the default CPU limit to be %v", defaultEsCpuRequest)
+	if cpu, isPresent := resources.Limits[v1.ResourceCPU]; isPresent {
+		t.Errorf("Exp. no default CPU limit, but got %v", cpu.String())
 	}
 	if resources.Requests[v1.ResourceMemory] != defaultEsMemory {
 		t.Errorf("Exp. the default memory request to be %v", defaultEsMemory)
@@ -36,39 +37,36 @@ func TestNewElasticsearchCRWhenNodeSelectorIsDefined(t *testing.T) {
 	expSelector := map[string]string{
 		"foo": "bar",
 	}
-	cluster := NewClusterLogging(
-		&logging.ClusterLogging{
-			Spec: logging.ClusterLoggingSpec{
-				LogStore: logging.LogStoreSpec{
-					Type: "elasticsearch",
-					ElasticsearchSpec: logging.ElasticsearchSpec{
-						NodeSelector: expSelector,
-					},
+	cluster := &logging.ClusterLogging{
+		Spec: logging.ClusterLoggingSpec{
+			LogStore: logging.LogStoreSpec{
+				Type: "elasticsearch",
+				ElasticsearchSpec: logging.ElasticsearchSpec{
+					NodeSelector: expSelector,
 				},
 			},
 		},
-	)
-	elasticsearchCR := cluster.newElasticsearchCR("test-app-name")
+	}
+	elasticsearchCR := newElasticsearchCR(cluster, "test-app-name")
 
 	if !reflect.DeepEqual(elasticsearchCR.Spec.Spec.NodeSelector, expSelector) {
 		t.Errorf("Exp. the nodeSelector to be %q but was %q", expSelector, elasticsearchCR.Spec.Spec.NodeSelector)
 	}
+
 }
 
 func TestNewElasticsearchCRWhenResourcesAreDefined(t *testing.T) {
-	cluster := NewClusterLogging(
-		&logging.ClusterLogging{
-			Spec: logging.ClusterLoggingSpec{
-				LogStore: logging.LogStoreSpec{
-					Type: "elasticsearch",
-					ElasticsearchSpec: logging.ElasticsearchSpec{
-						Resources: newResourceRequirements("100Gi", "", "120Gi", "500m"),
-					},
+	cluster := &logging.ClusterLogging{
+		Spec: logging.ClusterLoggingSpec{
+			LogStore: logging.LogStoreSpec{
+				Type: "elasticsearch",
+				ElasticsearchSpec: logging.ElasticsearchSpec{
+					Resources: newResourceRequirements("100Gi", "", "120Gi", "500m"),
 				},
 			},
 		},
-	)
-	elasticsearchCR := cluster.newElasticsearchCR("test-app-name")
+	}
+	elasticsearchCR := newElasticsearchCR(cluster, "test-app-name")
 
 	limitMemory := resource.MustParse("100Gi")
 	requestMemory := resource.MustParse("120Gi")
@@ -91,33 +89,29 @@ func TestNewElasticsearchCRWhenResourcesAreDefined(t *testing.T) {
 
 func TestDifferenceFoundWhenResourcesAreChanged(t *testing.T) {
 
-	cluster := NewClusterLogging(
-		&logging.ClusterLogging{
-			Spec: logging.ClusterLoggingSpec{
-				LogStore: logging.LogStoreSpec{
-					Type: "elasticsearch",
-					ElasticsearchSpec: logging.ElasticsearchSpec{
-						Resources: newResourceRequirements("100Gi", "", "120Gi", "500m"),
-					},
+	cluster := &logging.ClusterLogging{
+		Spec: logging.ClusterLoggingSpec{
+			LogStore: logging.LogStoreSpec{
+				Type: "elasticsearch",
+				ElasticsearchSpec: logging.ElasticsearchSpec{
+					Resources: newResourceRequirements("100Gi", "", "120Gi", "500m"),
 				},
 			},
 		},
-	)
-	elasticsearchCR := cluster.newElasticsearchCR("test-app-name")
+	}
+	elasticsearchCR := newElasticsearchCR(cluster, "test-app-name")
 
-	cluster = NewClusterLogging(
-		&logging.ClusterLogging{
-			Spec: logging.ClusterLoggingSpec{
-				LogStore: logging.LogStoreSpec{
-					Type: "elasticsearch",
-					ElasticsearchSpec: logging.ElasticsearchSpec{
-						Resources: newResourceRequirements("10Gi", "", "12Gi", "500m"),
-					},
+	cluster = &logging.ClusterLogging{
+		Spec: logging.ClusterLoggingSpec{
+			LogStore: logging.LogStoreSpec{
+				Type: "elasticsearch",
+				ElasticsearchSpec: logging.ElasticsearchSpec{
+					Resources: newResourceRequirements("10Gi", "", "12Gi", "500m"),
 				},
 			},
 		},
-	)
-	elasticsearchCR2 := cluster.newElasticsearchCR("test-app-name")
+	}
+	elasticsearchCR2 := newElasticsearchCR(cluster, "test-app-name")
 
 	_, different := isElasticsearchCRDifferent(elasticsearchCR, elasticsearchCR2)
 	if !different {
@@ -126,33 +120,29 @@ func TestDifferenceFoundWhenResourcesAreChanged(t *testing.T) {
 }
 
 func TestDifferenceFoundWhenNodeCountIsChanged(t *testing.T) {
-	cluster := NewClusterLogging(
-		&logging.ClusterLogging{
-			Spec: logging.ClusterLoggingSpec{
-				LogStore: logging.LogStoreSpec{
-					Type: "elasticsearch",
-					ElasticsearchSpec: logging.ElasticsearchSpec{
-						NodeCount: 1,
-					},
+	cluster := &logging.ClusterLogging{
+		Spec: logging.ClusterLoggingSpec{
+			LogStore: logging.LogStoreSpec{
+				Type: "elasticsearch",
+				ElasticsearchSpec: logging.ElasticsearchSpec{
+					NodeCount: 1,
 				},
 			},
 		},
-	)
-	elasticsearchCR := cluster.newElasticsearchCR("test-app-name")
+	}
+	elasticsearchCR := newElasticsearchCR(cluster, "test-app-name")
 
-	cluster = NewClusterLogging(
-		&logging.ClusterLogging{
-			Spec: logging.ClusterLoggingSpec{
-				LogStore: logging.LogStoreSpec{
-					Type: "elasticsearch",
-					ElasticsearchSpec: logging.ElasticsearchSpec{
-						NodeCount: 2,
-					},
+	cluster = &logging.ClusterLogging{
+		Spec: logging.ClusterLoggingSpec{
+			LogStore: logging.LogStoreSpec{
+				Type: "elasticsearch",
+				ElasticsearchSpec: logging.ElasticsearchSpec{
+					NodeCount: 2,
 				},
 			},
 		},
-	)
-	elasticsearchCR2 := cluster.newElasticsearchCR("test-app-name")
+	}
+	elasticsearchCR2 := newElasticsearchCR(cluster, "test-app-name")
 
 	_, different := isElasticsearchCRDifferent(elasticsearchCR, elasticsearchCR2)
 	if !different {
@@ -161,17 +151,16 @@ func TestDifferenceFoundWhenNodeCountIsChanged(t *testing.T) {
 }
 
 func TestDefaultRedundancyUsedWhenOmitted(t *testing.T) {
-	cluster := NewClusterLogging(
-		&logging.ClusterLogging{
-			Spec: logging.ClusterLoggingSpec{
-				LogStore: logging.LogStoreSpec{
-					Type:              "elasticsearch",
-					ElasticsearchSpec: logging.ElasticsearchSpec{},
-				},
+	cluster := &logging.ClusterLogging{
+		Spec: logging.ClusterLoggingSpec{
+			LogStore: logging.LogStoreSpec{
+				Type:              "elasticsearch",
+				ElasticsearchSpec: logging.ElasticsearchSpec{},
 			},
 		},
-	)
-	elasticsearchCR := cluster.newElasticsearchCR("test-app-name")
+	}
+
+	elasticsearchCR := newElasticsearchCR(cluster, "test-app-name")
 
 	if !reflect.DeepEqual(elasticsearchCR.Spec.RedundancyPolicy, elasticsearch.ZeroRedundancy) {
 		t.Errorf("Exp. the redundancyPolicy to be %q but was %q", elasticsearch.ZeroRedundancy, elasticsearchCR.Spec.RedundancyPolicy)
@@ -179,19 +168,17 @@ func TestDefaultRedundancyUsedWhenOmitted(t *testing.T) {
 }
 
 func TestUseRedundancyWhenSpecified(t *testing.T) {
-	cluster := NewClusterLogging(
-		&logging.ClusterLogging{
-			Spec: logging.ClusterLoggingSpec{
-				LogStore: logging.LogStoreSpec{
-					Type: "elasticsearch",
-					ElasticsearchSpec: logging.ElasticsearchSpec{
-						RedundancyPolicy: elasticsearch.SingleRedundancy,
-					},
+	cluster := &logging.ClusterLogging{
+		Spec: logging.ClusterLoggingSpec{
+			LogStore: logging.LogStoreSpec{
+				Type: "elasticsearch",
+				ElasticsearchSpec: logging.ElasticsearchSpec{
+					RedundancyPolicy: elasticsearch.SingleRedundancy,
 				},
 			},
 		},
-	)
-	elasticsearchCR := cluster.newElasticsearchCR("test-app-name")
+	}
+	elasticsearchCR := newElasticsearchCR(cluster, "test-app-name")
 
 	if !reflect.DeepEqual(elasticsearchCR.Spec.RedundancyPolicy, elasticsearch.SingleRedundancy) {
 		t.Errorf("Exp. the redundancyPolicy to be %q but was %q", elasticsearch.SingleRedundancy, elasticsearchCR.Spec.RedundancyPolicy)
@@ -207,19 +194,17 @@ func TestNotSplitRolesWhenNodeCountIsEq3(t *testing.T) {
 }
 
 func TestSplitRolesWhenNodeCountIsGt3(t *testing.T) {
-	cluster := NewClusterLogging(
-		&logging.ClusterLogging{
-			Spec: logging.ClusterLoggingSpec{
-				LogStore: logging.LogStoreSpec{
-					Type: "elasticsearch",
-					ElasticsearchSpec: logging.ElasticsearchSpec{
-						NodeCount: 4,
-					},
+	cluster := &logging.ClusterLogging{
+		Spec: logging.ClusterLoggingSpec{
+			LogStore: logging.LogStoreSpec{
+				Type: "elasticsearch",
+				ElasticsearchSpec: logging.ElasticsearchSpec{
+					NodeCount: 4,
 				},
 			},
 		},
-	)
-	elasticsearchCR := cluster.newElasticsearchCR("test-app-name")
+	}
+	elasticsearchCR := newElasticsearchCR(cluster, "test-app-name")
 
 	// verify that we have two nodes
 	if len(elasticsearchCR.Spec.Nodes) != 2 {
@@ -269,19 +254,17 @@ func TestSplitRolesWhenNodeCountIsGt3(t *testing.T) {
 }
 
 func createAndCheckSingleNodeWithNodeCount(t *testing.T, expectedNodeCount int32) {
-	cluster := NewClusterLogging(
-		&logging.ClusterLogging{
-			Spec: logging.ClusterLoggingSpec{
-				LogStore: logging.LogStoreSpec{
-					Type: "elasticsearch",
-					ElasticsearchSpec: logging.ElasticsearchSpec{
-						NodeCount: expectedNodeCount,
-					},
+	cluster := &logging.ClusterLogging{
+		Spec: logging.ClusterLoggingSpec{
+			LogStore: logging.LogStoreSpec{
+				Type: "elasticsearch",
+				ElasticsearchSpec: logging.ElasticsearchSpec{
+					NodeCount: expectedNodeCount,
 				},
 			},
 		},
-	)
-	elasticsearchCR := cluster.newElasticsearchCR("test-app-name")
+	}
+	elasticsearchCR := newElasticsearchCR(cluster, "test-app-name")
 
 	// verify that we have two nodes
 	if len(elasticsearchCR.Spec.Nodes) != 1 {
@@ -306,33 +289,29 @@ func createAndCheckSingleNodeWithNodeCount(t *testing.T, expectedNodeCount int32
 }
 
 func TestDifferenceFoundWhenNodeCountExceeds3(t *testing.T) {
-	cluster := NewClusterLogging(
-		&logging.ClusterLogging{
-			Spec: logging.ClusterLoggingSpec{
-				LogStore: logging.LogStoreSpec{
-					Type: "elasticsearch",
-					ElasticsearchSpec: logging.ElasticsearchSpec{
-						NodeCount: 3,
-					},
+	cluster := &logging.ClusterLogging{
+		Spec: logging.ClusterLoggingSpec{
+			LogStore: logging.LogStoreSpec{
+				Type: "elasticsearch",
+				ElasticsearchSpec: logging.ElasticsearchSpec{
+					NodeCount: 3,
 				},
 			},
 		},
-	)
-	elasticsearchCR := cluster.newElasticsearchCR("test-app-name")
+	}
+	elasticsearchCR := newElasticsearchCR(cluster, "test-app-name")
 
-	cluster = NewClusterLogging(
-		&logging.ClusterLogging{
-			Spec: logging.ClusterLoggingSpec{
-				LogStore: logging.LogStoreSpec{
-					Type: "elasticsearch",
-					ElasticsearchSpec: logging.ElasticsearchSpec{
-						NodeCount: 4,
-					},
+	cluster = &logging.ClusterLogging{
+		Spec: logging.ClusterLoggingSpec{
+			LogStore: logging.LogStoreSpec{
+				Type: "elasticsearch",
+				ElasticsearchSpec: logging.ElasticsearchSpec{
+					NodeCount: 4,
 				},
 			},
 		},
-	)
-	elasticsearchCR2 := cluster.newElasticsearchCR("test-app-name")
+	}
+	elasticsearchCR2 := newElasticsearchCR(cluster, "test-app-name")
 
 	_, different := isElasticsearchCRDifferent(elasticsearchCR, elasticsearchCR2)
 	if !different {
@@ -341,33 +320,29 @@ func TestDifferenceFoundWhenNodeCountExceeds3(t *testing.T) {
 }
 
 func TestDifferenceFoundWhenNodeCountExceeds4(t *testing.T) {
-	cluster := NewClusterLogging(
-		&logging.ClusterLogging{
-			Spec: logging.ClusterLoggingSpec{
-				LogStore: logging.LogStoreSpec{
-					Type: "elasticsearch",
-					ElasticsearchSpec: logging.ElasticsearchSpec{
-						NodeCount: 4,
-					},
+	cluster := &logging.ClusterLogging{
+		Spec: logging.ClusterLoggingSpec{
+			LogStore: logging.LogStoreSpec{
+				Type: "elasticsearch",
+				ElasticsearchSpec: logging.ElasticsearchSpec{
+					NodeCount: 4,
 				},
 			},
 		},
-	)
-	elasticsearchCR := cluster.newElasticsearchCR("test-app-name")
+	}
+	elasticsearchCR := newElasticsearchCR(cluster, "test-app-name")
 
-	cluster = NewClusterLogging(
-		&logging.ClusterLogging{
-			Spec: logging.ClusterLoggingSpec{
-				LogStore: logging.LogStoreSpec{
-					Type: "elasticsearch",
-					ElasticsearchSpec: logging.ElasticsearchSpec{
-						NodeCount: 5,
-					},
+	cluster = &logging.ClusterLogging{
+		Spec: logging.ClusterLoggingSpec{
+			LogStore: logging.LogStoreSpec{
+				Type: "elasticsearch",
+				ElasticsearchSpec: logging.ElasticsearchSpec{
+					NodeCount: 5,
 				},
 			},
 		},
-	)
-	elasticsearchCR2 := cluster.newElasticsearchCR("test-app-name")
+	}
+	elasticsearchCR2 := newElasticsearchCR(cluster, "test-app-name")
 
 	_, different := isElasticsearchCRDifferent(elasticsearchCR, elasticsearchCR2)
 	if !different {
@@ -375,36 +350,81 @@ func TestDifferenceFoundWhenNodeCountExceeds4(t *testing.T) {
 	}
 }
 
-func TestGenUUIDPreservedWhenNodeCountExceeds4(t *testing.T) {
-	cluster := NewClusterLogging(
-		&logging.ClusterLogging{
-			Spec: logging.ClusterLoggingSpec{
-				LogStore: logging.LogStoreSpec{
-					Type: "elasticsearch",
-					ElasticsearchSpec: logging.ElasticsearchSpec{
-						NodeCount: 3,
-					},
+func TestNewESCRNoTolerations(t *testing.T) {
+	expTolerations := []v1.Toleration{}
+
+	cluster := &logging.ClusterLogging{
+		Spec: logging.ClusterLoggingSpec{
+			LogStore: logging.LogStoreSpec{
+				Type:              "elasticsearch",
+				ElasticsearchSpec: logging.ElasticsearchSpec{},
+			},
+		},
+	}
+
+	elasticsearchCR := newElasticsearchCR(cluster, "test-app-name")
+	tolerations := elasticsearchCR.Spec.Spec.Tolerations
+
+	if !utils.AreTolerationsSame(tolerations, expTolerations) {
+		t.Errorf("Exp. the tolerations to be %v but was %v", expTolerations, tolerations)
+	}
+}
+
+func TestNewESCRWithTolerations(t *testing.T) {
+
+	expTolerations := []v1.Toleration{
+		v1.Toleration{
+			Key:      "node-role.kubernetes.io/master",
+			Operator: v1.TolerationOpExists,
+			Effect:   v1.TaintEffectNoSchedule,
+		},
+	}
+
+	cluster := &logging.ClusterLogging{
+		Spec: logging.ClusterLoggingSpec{
+			LogStore: logging.LogStoreSpec{
+				Type: "elasticsearch",
+				ElasticsearchSpec: logging.ElasticsearchSpec{
+					Tolerations: expTolerations,
 				},
 			},
 		},
-	)
-	elasticsearchCR := cluster.newElasticsearchCR("test-app-name")
+	}
+
+	elasticsearchCR := newElasticsearchCR(cluster, "test-app-name")
+	tolerations := elasticsearchCR.Spec.Spec.Tolerations
+
+	if !utils.AreTolerationsSame(tolerations, expTolerations) {
+		t.Errorf("Exp. the tolerations to be %v but was %v", expTolerations, tolerations)
+	}
+}
+
+func TestGenUUIDPreservedWhenNodeCountExceeds4(t *testing.T) {
+	cluster := &logging.ClusterLogging{
+		Spec: logging.ClusterLoggingSpec{
+			LogStore: logging.LogStoreSpec{
+				Type: "elasticsearch",
+				ElasticsearchSpec: logging.ElasticsearchSpec{
+					NodeCount: 3,
+				},
+			},
+		},
+	}
+	elasticsearchCR := newElasticsearchCR(cluster, "test-app-name")
 	dataUUID := esutils.GenerateUUID()
 	elasticsearchCR.Spec.Nodes[0].GenUUID = &dataUUID
 
-	cluster = NewClusterLogging(
-		&logging.ClusterLogging{
-			Spec: logging.ClusterLoggingSpec{
-				LogStore: logging.LogStoreSpec{
-					Type: "elasticsearch",
-					ElasticsearchSpec: logging.ElasticsearchSpec{
-						NodeCount: 4,
-					},
+	cluster = &logging.ClusterLogging{
+		Spec: logging.ClusterLoggingSpec{
+			LogStore: logging.LogStoreSpec{
+				Type: "elasticsearch",
+				ElasticsearchSpec: logging.ElasticsearchSpec{
+					NodeCount: 4,
 				},
 			},
 		},
-	)
-	elasticsearchCR2 := cluster.newElasticsearchCR("test-app-name")
+	}
+	elasticsearchCR2 := newElasticsearchCR(cluster, "test-app-name")
 
 	diffCR, different := isElasticsearchCRDifferent(elasticsearchCR, elasticsearchCR2)
 	if !different {
@@ -417,35 +437,31 @@ func TestGenUUIDPreservedWhenNodeCountExceeds4(t *testing.T) {
 }
 
 func TestGenUUIDPreservedWhenNodeCountChanges(t *testing.T) {
-	cluster := NewClusterLogging(
-		&logging.ClusterLogging{
-			Spec: logging.ClusterLoggingSpec{
-				LogStore: logging.LogStoreSpec{
-					Type: "elasticsearch",
-					ElasticsearchSpec: logging.ElasticsearchSpec{
-						NodeCount: 1,
-					},
+	cluster := &logging.ClusterLogging{
+		Spec: logging.ClusterLoggingSpec{
+			LogStore: logging.LogStoreSpec{
+				Type: "elasticsearch",
+				ElasticsearchSpec: logging.ElasticsearchSpec{
+					NodeCount: 1,
 				},
 			},
 		},
-	)
-	elasticsearchCR := cluster.newElasticsearchCR("test-app-name")
+	}
+	elasticsearchCR := newElasticsearchCR(cluster, "test-app-name")
 	dataUUID := esutils.GenerateUUID()
 	elasticsearchCR.Spec.Nodes[0].GenUUID = &dataUUID
 
-	cluster = NewClusterLogging(
-		&logging.ClusterLogging{
-			Spec: logging.ClusterLoggingSpec{
-				LogStore: logging.LogStoreSpec{
-					Type: "elasticsearch",
-					ElasticsearchSpec: logging.ElasticsearchSpec{
-						NodeCount: 3,
-					},
+	cluster = &logging.ClusterLogging{
+		Spec: logging.ClusterLoggingSpec{
+			LogStore: logging.LogStoreSpec{
+				Type: "elasticsearch",
+				ElasticsearchSpec: logging.ElasticsearchSpec{
+					NodeCount: 3,
 				},
 			},
 		},
-	)
-	elasticsearchCR2 := cluster.newElasticsearchCR("test-app-name")
+	}
+	elasticsearchCR2 := newElasticsearchCR(cluster, "test-app-name")
 
 	diffCR, different := isElasticsearchCRDifferent(elasticsearchCR, elasticsearchCR2)
 	if !different {
